@@ -5,4 +5,4 @@
 
 from .decr_timer import *
 from .decr_run_times import *
-from tomorrow3 import threads as m_threads
+from .decr_reids_cache import RedisCache
\ No newline at end of file
