@@ -18,7 +18,7 @@ def timer_cost(func):
         rs = func(*args, **argus)
         time_end = time.time()
         cost_time = round((time_end * 1000 - time_begin * 1000) / 1000, 2)
-        logger.info(f"function {func.__name__} cost time:{cost_time}S")
+        logger.info(f"{func.__name__} cost time:{cost_time}S")
         return rs
 
     return time_cal
